@@ -1,7 +1,7 @@
 /**
  * search.c - Search dialog for searching the files in the SciteProj project
  *
- *  Copyright 2011 Andreas Rönnquist
+ *  Copyright 2011-2012 Andreas Rönnquist
  *
  * This file is part of SciteProj
  *
@@ -22,6 +22,10 @@
 #include <gdk/gdkkeysyms.h>
 #include <unistd.h>
 #include <string.h>
+#include <glib/gi18n.h>
+#include <glib.h>
+
+#include <locale.h>
 
 #include "search.h"
 #include "tree_manipulation.h"
@@ -147,14 +151,20 @@ void search_dialog()
 	GtkWidget *find_label;
 	
 	GtkWidget *close_button;
+
+	GtkWidget *scrolled_win;
+	
+#if GTK_MAJOR_VERSION>=3
+	GtkWidget *grid;
+#else
+	GtkWidget *hbox;
+	
+	GtkWidget *vbox;
 	GtkWidget *close_hbox;
 	
 	GtkWidget *check_button_box;
 
-	GtkWidget *scrolled_win;
-	
-	GtkWidget *hbox;
-	GtkWidget *vbox;
+#endif
 	
 	Data *data;
 	
@@ -163,12 +173,14 @@ void search_dialog()
 	data->search_list=list;
 	
 	data->prefs=gPrefs;
+	
+	data->error=NULL;
 
 	// Make the dialog
 	window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_container_set_border_width(GTK_CONTAINER(window), 8);
 	
-	gtk_window_set_title(GTK_WINDOW(window),"Search project");
+	gtk_window_set_title(GTK_WINDOW(window),_("Search project"));
 	
 	// Set up size and position from prefs
 	gtk_window_resize(GTK_WINDOW(window), gPrefs.search_width, gPrefs.search_height);
@@ -177,15 +189,29 @@ void search_dialog()
 		gtk_window_move(GTK_WINDOW(window),gPrefs.search_xpos,gPrefs.search_ypos);
 	}
 	
+#if GTK_MAJOR_VERSION>=3
+	grid=gtk_grid_new();
+	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
+#else
 	hbox=gtk_hbox_new(FALSE,8);
+#endif
 	
-	find_label=gtk_label_new("Find What:");
+	find_label=gtk_label_new(_("Find What:"));
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach(GTK_GRID(grid),find_label,0,0,1,1);
+#else
 	gtk_box_pack_start(GTK_BOX(hbox),find_label,FALSE,TRUE,5);
+#endif
+	
 		
 	data->search_string_entry=gtk_entry_new();
 	gtk_entry_set_visibility(GTK_ENTRY(data->search_string_entry),TRUE);
 	
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach_next_to(GTK_GRID(grid),data->search_string_entry,find_label,GTK_POS_RIGHT,3,1);
+#else
 	gtk_box_pack_start(GTK_BOX(hbox),data->search_string_entry,TRUE,TRUE,5);
+#endif
 	
 	/*
 	GtkBox *hbox=gtk_hbox_new(TRUE,0);
@@ -196,9 +222,12 @@ void search_dialog()
 	data->number_of_results=0;
 	
 	data->search_button=gtk_button_new_from_stock(GTK_STOCK_FIND);
-	
+
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach_next_to(GTK_GRID(grid),data->search_button,data->search_string_entry,GTK_POS_RIGHT,1,1);
+#else
 	gtk_box_pack_start(GTK_BOX(hbox),data->search_button,FALSE,FALSE,5);
-	
+		
 	vbox=gtk_vbox_new(FALSE,8);
 	
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
@@ -206,24 +235,39 @@ void search_dialog()
 	
 	check_button_box=gtk_hbox_new(FALSE,8);
 	
-	match_case_checkbutton=gtk_check_button_new_with_label("Match case");
+
+#endif
+
+	match_case_checkbutton=gtk_check_button_new_with_label(_("Match case"));
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(match_case_checkbutton),gPrefs.search_match_case);
 	
 	//gtk_table_attach(GTK_TABLE(table),match_case_checkbutton,0,2,1,2, GTK_SHRINK, GTK_SHRINK, 0,0);
+#if GTK_MAJOR_VERSION<3
 	gtk_box_pack_start(GTK_BOX(check_button_box),match_case_checkbutton,FALSE,TRUE,5);
+#endif
+	//gtk_grid_attach_next_to(GTK_GRID(grid),match_case_checkbutton,
 	
 	
-	match_whole_words_only_checkbutton=gtk_check_button_new_with_label("Match whole word only");
+	match_whole_words_only_checkbutton=gtk_check_button_new_with_label(_("Match whole word only"));
 	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(match_whole_words_only_checkbutton),gPrefs.search_match_whole_words);
 	
 	//gtk_table_attach(GTK_TABLE(table),match_whole_words_only_checkbutton,2,4,1,2, GTK_SHRINK,GTK_SHRINK, 0,0);
+
+#if GTK_MAJOR_VERSION>=3
+	
+	gtk_grid_attach(GTK_GRID(grid),match_case_checkbutton,0,1,1,1);
+	
+	gtk_grid_attach(GTK_GRID(grid),match_whole_words_only_checkbutton,1,1,1,1);
+#else	
 	gtk_box_pack_start(GTK_BOX(check_button_box),match_whole_words_only_checkbutton,FALSE,TRUE,5);
 	
-	
 	gtk_box_pack_start(GTK_BOX(vbox),check_button_box,FALSE,FALSE,0);
 	
+#endif
+	
+	
 	
 	
 	treeview=gtk_tree_view_new();
@@ -245,25 +289,49 @@ void search_dialog()
 	
 	gtk_container_add(GTK_CONTAINER(scrolled_win),treeview);
 	
+#if GTK_MAJOR_VERSION>=3
+	
+	gtk_widget_set_vexpand(scrolled_win,TRUE);
+	gtk_widget_set_hexpand(scrolled_win,TRUE);
+	
+	gtk_grid_attach(GTK_GRID(grid),scrolled_win,0,2,5,1);
+#else
 	gtk_box_pack_start(GTK_BOX(vbox),scrolled_win,TRUE,TRUE,0);
 	
+#endif
+	
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(scrolled_win),
 					    GTK_SHADOW_IN);
 	
 	close_button=gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 	
+#if GTK_MAJOR_VERSION<3
 	close_hbox=gtk_hbox_new(FALSE,8);
+#endif
 	
 	data->result_label=gtk_label_new(NULL);
 	
+	gtk_label_set_text(GTK_LABEL(data->result_label),"");
+	
+#if GTK_MAJOR_VERSION>=3
+	gtk_grid_attach(GTK_GRID(grid),data->result_label,0,3,1,1);
+
+	gtk_grid_attach(GTK_GRID(grid),close_button,4,3,1,1);
+	
+	// add the table to the window
+	gtk_container_add(GTK_CONTAINER(window),grid);
+	
+#else
 	gtk_box_pack_start(GTK_BOX(close_hbox),data->result_label,FALSE,FALSE,0);
 	
 	gtk_box_pack_end(GTK_BOX(close_hbox),close_button,FALSE,FALSE,5);
 	
 	gtk_box_pack_start(GTK_BOX(vbox),close_hbox,FALSE,FALSE,0);
 	
-	// add the table to the window
 	gtk_container_add(GTK_CONTAINER(window),vbox);
+#endif
+	
+	
 			
 	g_signal_connect(G_OBJECT(window), "destroy",G_CALLBACK (destroy_search_dialog_cb), &window);
 	g_signal_connect(G_OBJECT(close_button),"clicked",G_CALLBACK(close_button_pressed_cb),data);
@@ -543,7 +611,7 @@ static gpointer thread_func(Data *data)
 		gchar *error_message=NULL;
 		data->error=NULL;
 		
-		error_message=g_strdup_printf("There was problems opening the following files in the project:\n\n");
+		error_message=g_strdup_printf(_("There was problems opening the following files in the project:\n\n"));
 					
 		while((file_error_list)) {
 			
@@ -556,7 +624,7 @@ static gpointer thread_func(Data *data)
 			file_error_list=g_list_next(file_error_list);
 		}
 		
-		gchar *temp2=g_strconcat(error_message,"\nThey couldn't be opened for reading in the search.\n",NULL);
+		gchar *temp2=g_strconcat(error_message,_("\nThey couldn't be opened for reading in the search.\n"),NULL);
 		
 		g_free(error_message);
 		error_message=temp2;
@@ -601,7 +669,12 @@ static void search_button_clicked_cb(GtkButton *button,gpointer user_data)
 			g_atomic_int_set(&threaded_flag,1);
 			
 			data->queue=g_async_queue_new();
+
+#if ((GLIB_MAJOR_VERSION>=2) && (GLIB_MINOR_VERSION>=31))
+			thread=g_thread_new("search_thread",(GThreadFunc)thread_func,NULL);
+#else			
 			thread=g_thread_create((GThreadFunc)thread_func,data,TRUE,NULL);
+#endif
 			
 			is_searching=TRUE;
 			
@@ -610,7 +683,7 @@ static void search_button_clicked_cb(GtkButton *button,gpointer user_data)
 		} else {
 			// string to search for has a length of zero.
 			GtkWidget *warningDialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, 
-				"Please enter a text to search for!\n"
+				_("Please enter a text to search for!\n")
 				);
 			gtk_dialog_run(GTK_DIALOG(warningDialog));
 			gtk_widget_destroy(warningDialog);
@@ -701,7 +774,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 	
 	// convert to a full path
 	if (!relative_path_to_abs_path(temppath, &absFilePath, get_project_directory(), &err)) {
-		printf("Error:%s\n",err->message);
+		printf(_("Error:%s\n"),err->message);
 		goto EXITPOINT;
 	}
 
@@ -715,7 +788,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 		
 		if (!launch_scite(run_options,&err)) {
 			
-			printf("Error:%s\n",err->message);
+			printf(_("Error:%s\n"),err->message);
 			
 			//goto EXITPOINT;
 			
@@ -761,7 +834,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 			
 			gchar *statusbar_text=NULL;
 			
-			statusbar_text=g_strdup_printf("Opened %s",remove_newline(get_filename_from_full_path(command)));
+			statusbar_text=g_strdup_printf(_("Opened %s"),remove_newline(get_filename_from_full_path(command)));
 			
 			set_statusbar_text(statusbar_text);
 			
@@ -769,7 +842,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 		} else {
 
 			if (err) {
-				printf("Error:%s\n",err->message);
+				printf(_("Error:%s\n"),err->message);
 			}
 			
 		}
@@ -799,7 +872,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 			
 			gchar *statusbar_text=NULL;
 			
-			statusbar_text=g_strdup_printf("Opened %s",remove_newline(get_filename_from_full_path(command)));
+			statusbar_text=g_strdup_printf(_("Opened %s"),remove_newline(get_filename_from_full_path(command)));
 			
 			set_statusbar_text(statusbar_text);
 			
@@ -808,7 +881,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView, GtkTreePath *path, GtkT
 			
 			printf("goto didn't work...\n");
 			if (err) {
-				printf("Error:%s\n",err->message);
+				printf(_("Error:%s\n"),err->message);
 			}
 			
 		}
@@ -853,15 +926,15 @@ static void setup_tree_view(GtkWidget *treeview)
 	GtkTreeViewColumn *column;
 	
 	renderer=gtk_cell_renderer_text_new();
-	column=gtk_tree_view_column_new_with_attributes("Filename",renderer,"text",FILENAME,NULL);
+	column=gtk_tree_view_column_new_with_attributes(_("Filename"),renderer,"text",FILENAME,NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview),column);
 		
 	renderer=gtk_cell_renderer_text_new();
-	column=gtk_tree_view_column_new_with_attributes("Line",renderer,"text",LINENUMBER,NULL);
+	column=gtk_tree_view_column_new_with_attributes(_("Line"),renderer,"text",LINENUMBER,NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview),column);
 	
 	renderer=gtk_cell_renderer_text_new();
-	column=gtk_tree_view_column_new_with_attributes("File contents",renderer,"text",FILE_CONTENTS,NULL);
+	column=gtk_tree_view_column_new_with_attributes(_("File contents"),renderer,"text",FILE_CONTENTS,NULL);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview),column);
 }
 
@@ -899,6 +972,7 @@ static void stop_search(gpointer user_data)
 		gdk_window_set_cursor(gtk_widget_get_window(window),NULL);
 		
 		// If we have error results from the search - open a dialog, and show it
+		
 		if (data->error!=NULL) {
 			
 			if (data->prefs.search_alert_file_warnings) {
@@ -911,7 +985,7 @@ static void stop_search(gpointer user_data)
 		
 		}
 
-		gchar *string=g_strdup_printf("Found %d elements",data->number_of_results);
+		gchar *string=g_strdup_printf(_("Found %d elements"),data->number_of_results);
 			
 		gtk_label_set_text(GTK_LABEL(data->result_label),string);
 		
@@ -920,7 +994,7 @@ static void stop_search(gpointer user_data)
 		// Give a dialog if the search didn't find anything.
 		if (data->number_of_results==0) {
 			GtkWidget *dialog=gtk_message_dialog_new(NULL,
-				GTK_DIALOG_MODAL,GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,"The search didn't give any results.");
+				GTK_DIALOG_MODAL,GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,_("The search didn't give any results."));
 			gtk_dialog_run(GTK_DIALOG(dialog));
 			gtk_widget_destroy(dialog);
 		}
